==> haskell-quickcheck-assertions-0.3.0-302-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-9usDdWrO2rIAErraoHAcsm
key:                  quickcheck-assertions-0.3.0-9usDdWrO2rIAErraoHAcsm
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  99736e9f5914e1c74de400a4daa6fb31
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-9usDdWrO2rIAErraoHAcsm
depends:
    QuickCheck-2.14.3-3PB7cbCGvbeCmx5SHgwMna base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-304-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-8NNpxWGks8c2hosWwyn28y
key:                  quickcheck-assertions-0.3.0-8NNpxWGks8c2hosWwyn28y
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  43d311d14f2a9ae7cbc1085a556ff4f9
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-8NNpxWGks8c2hosWwyn28y
depends:
    QuickCheck-2.14.3-9Q0kCzH4SfmKZwwhPvduaz base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
